@@ -7,7 +7,11 @@ import os
 
 import boto3
 
-from .exceptions import ForceChangePasswordException
+from .exceptions import (
+    ForceChangePasswordException,
+    SoftwareTokenMFAChallengeException,
+    SMSMFAChallengeException,
+)
 
 # https://github.com/aws/amazon-cognito-identity-js/blob/master/src/AuthenticationHelper.js#L22
 N_HEX = (
@@ -115,6 +119,8 @@ def calculate_u(big_a, big_b):
 
 class AWSSRP:
 
+    SMS_MFA_CHALLENGE = "SMS_MFA"
+    SOFTWARE_TOKEN_MFA_CHALLENGE = "SOFTWARE_TOKEN_MFA"
     NEW_PASSWORD_REQUIRED_CHALLENGE = "NEW_PASSWORD_REQUIRED"
     PASSWORD_VERIFIER_CHALLENGE = "PASSWORD_VERIFIER"
 
@@ -277,6 +283,14 @@ class AWSSRP:
                     "Change password before authenticating"
                 )
 
+            if tokens.get("ChallengeName") == self.SMS_MFA_CHALLENGE:
+                raise SMSMFAChallengeException("Do SMS MFA", tokens)
+
+            if tokens.get("ChallengeName") == self.SOFTWARE_TOKEN_MFA_CHALLENGE:
+                raise SoftwareTokenMFAChallengeException(
+                    "Do Software Token MFA", tokens
+                )
+
             return tokens
 
         raise NotImplementedError(
